@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.1.5" or
-    raise "ruby lib version (2.1.5) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "2.1.6" or
+    raise "ruby lib version (2.1.6) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.1/i386-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,8 +13,8 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "1"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "273"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.1.5/bin/install -c '
+  CONFIG["PATCHLEVEL"] = "336"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.1.6/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby21"
@@ -77,13 +77,13 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.1"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
-  CONFIG["strict_warnflags"] = "-ansi -std=iso9899:199409"
+  CONFIG["strict_warnflags"] = "-std=iso9899:1999"
   CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
@@ -142,9 +142,9 @@ module RbConfig
   CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.1.5/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.1.5/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.1.5/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.1.6/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.1.6/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.1.6/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -177,23 +177,23 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd5.7"
+  CONFIG["target_os"] = "openbsd5.8"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "i386"
-  CONFIG["target"] = "i386-unknown-openbsd5.7"
-  CONFIG["host_os"] = "openbsd5.7"
+  CONFIG["target"] = "i386-unknown-openbsd5.8"
+  CONFIG["host_os"] = "openbsd5.8"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "i386"
-  CONFIG["host"] = "i386-unknown-openbsd5.7"
+  CONFIG["host"] = "i386-unknown-openbsd5.8"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.7"
+  CONFIG["build_os"] = "openbsd5.8"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "i386"
-  CONFIG["build"] = "i386-unknown-openbsd5.7"
-  CONFIG["RUBY_RELEASE_DATE"] = "2014-11-13"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.5"
+  CONFIG["build"] = "i386-unknown-openbsd5.8"
+  CONFIG["RUBY_RELEASE_DATE"] = "2015-04-13"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.6"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
